;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;	   		"CONNETED" LIBRARY
;		INCLUDES ALL THE C language  FINCTIONS
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;			M_LocateCursor
; A MACRO THAT SHIFTS THE CURSOR AT THE VALUES GIVEN IN "ROW", "COL"
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

M_LocateCursor  macro row,col

		mov     ah,2
		mov     dh,row
		mov     dl,col
		mov     bh,0
		int     10h

endm

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;			DELAY	MACRO	X
;A MACRO THAT PRFORMS THE SAME FUNCTION AS "delay"  IN C LANGUAGE
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

DELAY	macro    x

		PUSH	AX
		PUSH	DX
		PUSH	CX


		mov	ah,86h
		mov	cx,x
		mov	dx,0
		int	15h

		POP	CX
		POP	DX
		POP	AX
endm

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;			DATA	SEGENT
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_DATA segment word public 'DATA'

	FOR_LSB 	db	?	;VALUES FOR THE BAUD RATE
	FOR_MSB		db	?       ;VALUES FOR THE BAUD RATE
	CUR_ROW		db	?       ;VALUES FOR THE ROW
	CUR_COL		db	?	;VALUES FOR THE COL

	PORT		dw	2f8h	;PORT ADDRESS
	L_CTRL		dw	?	;LINE CONTROL REGISTER
	M_CTRL		dw	?	;MODEM CONTROL REGISTER
	M_STAT		dw	?	;MODEM STATUS REGISTER
	L_STAT		dw	?	;LINE STATUS REGISTER
	TR		dw	?	;TRANSMITTER REGISTER
	RC		dw	?	;RECEIEVER REGISTER
	LSB		dw	?	;LSB REGISTER (FOR BAUD RATE)
	MSB		dw	?       ;MSB REGISTER (FOR BAUD RATE)

	NO_MODEM    db      'Modem Not Found........ $'
					;DISPLAYED WHEN MODEM NOT PRESENT ON THE PORT

	no_echo	 	db	'ate0',0dh	;INITIAL PARAMETER
	hang_1		db	'+++'		;STRING FOR HANGING UP
	hang_2		db	'ath',0dh       ;STRING FOR HANGING UP
	answer		db	'ata',0dh       ;STRING FOR ANSER

_DATA ends

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;			DECLATATION OF THE PROCEDURES
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	public _ASK_PORT		;ASK THE PORT FROM THE USER
	public _INITIALIZE		;INITIALIZE THE PORT
	public _CHAT		 	;MAIN CHAT PROCEDURE
	public _SCROLL_UP		;TO SCROLL THE TERMINAL WINDOW UP
	public _ENTER_PRESSED		;NEW LINE WHEN THE ENTER IS PRESSED
	public _SET_CURSOR		;INCREASE THE COLUMN AFTER ANY WORD TYPED
	public _IF_BUFFER_EMPTY		;CHECK IF DATA HAS BEEN SENT
	public _SEND_STRING		;SEND STRING TO THE MODEM
	public _BACK_SPACE		;MANAGE BACK SPACE
	public _HANG_UP			;PROCEDURE FOR HANIGNIG UP
	public _ANSWER			;ANSWER THE INCOMING CALL
	public _CLRSCR			;CLEAR THE SCREEN
	public _DISPLAY_STRING		;FOR DISPLAYING ANY STRING
	public _EXIT			;EXIT

_TEXT segment byte public 'CODE'
	  assume cs:_TEXT,ds:_DATA,es:_DATA

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;				_ASK_PORT PROC...
;ASKS THE PORT AND QUITS IF NOT FOUND...INITILIZE THE REGISTER ACCORING THE PORT
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_ASK_PORT	proc near


	MOV     AH,7			;INPUT WITHOUT ECHO
	INT     21H

	CMP     AL,'1'			;CHECK IF COM1 SELECTED
	JE      FOR_COM1		;IF YES: GOTO FOR_COM1

	CMP     AL,'2'			;CHECK IF COM2 SELECTED
	JE      FOR_COM2                ;IF YES: GOTO FOR_COM2

	CALL	_ASK_PORT		;IF ANYTHING ELSE TYPED,ASK AGAIN

	FOR_COM2:			;IF COM2 SELECTED

	MOV     DX,2feh                 ;CHECK MODEM STATUS TO CONFIRM THE PRESENCE
	IN      AL,DX                   ;INPUT FROM THE MODEM STATUS REGISTER

	CMP     AL,30H
	JNE     exit2 		        ;IF PRESENT:CONTINUE
					;ELSE: DIAPLEY STRING AND EXIT

	MOV     PORT,2F8H		;PUT THE VALUE OF THE PORT
	MOV     L_CTRL,2F8H+3H        	;LINE CONTROL REGISTER
	MOV     M_CTRL,2F8H+4H        	;MODEM CONTROL REGISTER
	MOV     L_STAT,2F8H+5H        	;LINE STATUS REGISTER
	MOV     M_STAT,2F8H+6H        	;MODEM STATUS REGISTER
	MOV     TR,2F8H+0H            	;TRANSMITTER HOLDER REGISTER
	MOV     RC,2F8H+0H           	;RECIEVER REGISTER
	MOV     LSB,2F8H+0H         	;FOR DLL i.e BAUD RATE
	MOV     MSB,2F8H+1H         	;FOR MDD i.e BAUD RATE

	JMP	 BYE			;AFTER THIS INITIALIZATION,QUIT THE PROC

	FOR_COM1:			;IF COM1 SELECTED

	MOV     DX,3FEh	                ;CHECK MODEM STATUS TO CONFIRM THE PRESENCE
	IN      AL,DX			;INPUT FROM THE MODEM STATUS REGISTER

	CMP	AL,30h
	JNE     exit2               	;IF PRESENT: CONTINUE
					;ELSE: DISPLAY STRING AND EXIT

	MOV     PORT,3F8H		;PUT THE VALUE OF THE PORT
	MOV     L_CTRL,3F8H+3H        	;LINE CONTROL REGISTER
	MOV     M_CTRL,3F8H+4H        	;MODEM CONTROL REGISTER
	MOV     L_STAT,3F8H+5H        	;LINE STATUS REGISTER
	MOV     M_STAT,3F8H+6H        	;MODEM STATUS REGISTER
	MOV     TR,3F8H+0H        	;TRANSMITTER HOLDER REGISTER
	MOV     RC,3F8H+0H         	; RECIEVER REGISTER
	MOV     LSB,3F8H+0H        	;FOR DLL i.e BAUD RATE
	MOV     MSB,3F8H+1H        	;FOR MDD i.e BAUD RATE

	JMP	BYE			;AFTER THIS INITIALIZATION,QUIT THE PROC

	exit2:				;COME HERE WHEN NO PORT FOUND

	CALL	_CLRSCR			;CLEAR SCREEN
	LEA     DX,NO_MODEM		;DISPLAY THE NO MODEM FOUND STRING
	CALL	_DISPLAY_STRING
	CALL	_EXIT                   ;EXIT

   BYE:					;LABEL:WHEN THE PORT FOUND

	RET

_ASK_PORT	endp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;		INITIALIZE	PROC
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_INITIALIZE proc near


	push    ax
	push    dx
	push    si
	push	di

	MOV     FOR_LSB,0CH		;VALUES FOR THE LSB
	MOV     FOR_MSB,00H             ;VALUES FOR THE MSB

	mov     al,10000000b   		;SET BIT 8 FOR BAUD PATCHES
	mov     dx,L_CTRL               ;MOVE THE LINE CONTROL REGISTER ADDRESS IN THE DX
	out     dx,al			;SEND THIS TO THE REGISTER

	mov     dx,LSB   		;SET THE LSB REGISTER
	mov     al,FOR_LSB
	out     dx,al

	mov     dx,MSB  		;SET THE MSB REFISTER
	mov     al,FOR_MSB
	out     dx,al

	mov     dx,L_CTRL               ;CLOSE THE LSB AND MSB ACCESS
	mov     al,00000011b
	out     dx,al

	mov     dx,M_CTRL		;SET THE MODEM CONTROL REGISTER
	mov     al,3
	out     dx,al

	mov	di,offset no_echo	;SET THE INTIAL STRIING
	mov	cx,5
	CALL	_SEND_STRING		;CALL THIS PROCEDURE FOR SENDING THE STRING OT THE MODEM


	pop	di
	pop     si
	pop     dx
	pop     ax

	ret

_INITIALIZE	endp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;		CHAT	PROC...
;  THIS IS THE MAIN TERNIAL WINDOWS PROCEDURE...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_CHAT	proc near

	M_LocateCursor 4,0              ;LOCATE THE CURSOR
	DELAY	5
   FOR:
	MOV     AH,6                	;INPUT WITHOUT ECHO
	MOV     DL,0FFH
	INT     21H
	JZ      NO_CHARS            	;IF NO INPUT GOTO LABEL "NO_CHARS"

	CMP     AL,0DH	            	;IF: enter PRESSED
	JE      ENTER_OUT               ;GOTO: ENTER_OUT

	CMP	AL,10h		        ;ctrl - h for hanging up
	JE	hang                    ;GOTO: hang

	CMP	AL,8h	             	;ctrl - h for hanging up
	JE	BACKSPACE               ;GOTO: BACKSPACE

	CMP     AL,1			;ctrl-a for answer
	JE	ANSWER2			;GOTO ANSWER2

	CMP     AL,05H               	;CTRL-E FOR EXIT
	JE      OOPS                    ;GET OUT OF THE LOOP

	MOV     AH,9                 	;OUTPUT THE CHAR FOR ECHO PURPOSE
	mov	bh,0
	mov     BL,1110b
	MOV	CX,1
	INT     10H


	CALL	_SET_CURSOR             ;SET CURSOR AFTER THE OUTPUT

	back_hang:			;COME BACK HERE AFTER HANGING UP

	BACK1: 		                ;BACK AFTER "ENTER_OUT"

	MOV     DX,PORT              	;MOVE THE PORT NUMBER I.E 2F8
	OUT     DX,AL                	;OUTPUT THE CHAR TO THE 2F8 i.e. PORT

	CALL	_IF_BUFFER_EMPTY	;WAIT UNTILL THE CHARACHTER HAS BEEN SENT

	NO_CHARS:                     	;A JUMP IF NO INPUT IS GIVEN

	MOV     DX,L_STAT            	;LINE STATUS REGISTER
	IN      AL,DX                	;LINE STATUS REGISTER
	TEST    AL,00000001B         	;CHECK TO SEE IF ANY THING IS RECEIVED i.e.RBR IS FULL
	JNZ     ON_SCREEN               ;IF YES: GOTO "ON_SCEEN" TO OUT PUT IT

   BACK_FROM_ON_SCREEN:			;BACK AFTER THE "ON_SCREEN"

	MOV      AH,3                	;GETTING THE CURSOR POSITION
	MOV      BH,0
	INT      10H

	CMP      DL,79               	;IF THE LINE IS FULL,PRESS ENTER
	JE       ENTER_OUT		;GOTO "ENTER_OUT"

   BACK_AFTER_NEW_LINE:			;COME BACK HERE

	CMP	  DH,24			;IF THE SCREEN IS FULL
	JE	  SCROLL		;GOTO SCROLL

	BACK_FROM_SCROLL:		;COME  BACK HERE AFTER THE SCROLL

	JMP     FOR   ;END OF MAIN LOOP::GO TO THE BEGTINNING OF THE LOOP


   ;;;;;;;;;;THIS IS THE LABEL FOR OUTOUTTING THE CHARACHETER RECEIVED;;;;;;;;;;;

  ON_SCREEN:

	MOV     DX,PORT
	IN      AL,DX               	;GET FROM PORT

	CMP     AL,0DH		    	;IF IT IS ENTER GOTO: ENTER_IN
	JE      ENTER_IN

	CMP	AL,10                   ;A FILTER
	JE	BACK2

	MOV     AH,9               	;OUTPUT THE CHAR RECEIVED
	MOV	BH,0
	MOV	BL,1010B
	MOV	CX,1
	INT     10H

	CALL	_SET_CURSOR		;SET THE CURSOR AFTER THE OUTPUT

 BACK2:
	JMP     BACK_FROM_ON_SCREEN	;GO BACK TO THE "FOR" LOOP  AFTER OUTPUT


     ;;;;;;;;;;;;;;;;;;;;;;;; FOR THE NEW LINE AFTER ENTER;;;;;;;;;;;;;;;;;

	BACKSPACE:			;CALLED WHEN BACKSPACE USED
	CALL	_BACK_SPACE		;CALL THE _BACK_SPACE
	JMP 	FOR			;GO BACK TO THE LOOP

	ENTER_IN:                       ;COME HERE WHEN ENTER RECIEVED
	CALL	_ENTER_PRESSED		;CALL _ENTER_PRESSED
	jmp	 BACK2			;GO BACK TO "BACK2"

	ENTER_OUT:			;WHEN THE ENTER IS PRESSED
	CALL	_ENTER_PRESSED		;CALL _ENTER_PRESSED
	jmp	BACK1			;GO BACK TO "BACK1"

	hang:				;COME HERE FOR HANGING UP
	CALL	_HANG_UP		;CALL _HANG_UP
	JMP	BACK_HANG		;GO BACK TO THE "FOR LOOP"

	SCROLL:				;COME HERE WHEN SCROLLING IS NEEDED
	CALL	_SCROLL_UP
	JMP	 FOR                    ;GO BACK TO THE "FOR LOOP"

	ANSWER2:			;WHEN ANSWERING THE CALL
	CALL	_ANSWER
	JMP	 FOR			;GO BACK TO THE "FOR LOOP"

	;;;;;;;;;;;;;;;;;; FOR EXIT WHEN "CTRL-E" PRESSED;;;;;;;;;;;;;;;;;;
	 OOPS:
	 CALL	_HANG_UP		;CALL HANG_UP BEFORE EXITING

	ret

_CHAT	endp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;		_SET_CURSOR	PROC
;       	THIS IS CALLED FROM THE CHAT PROC
;	INCREASE THE COLUMN FOR THE CUSOR,SINCE THE 09h:21 DOESN'T DO IT
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_SET_CURSOR	proc near

	push    ax
	push    dx
	push    si
	push    di

	MOV     AH,3			;GET CUSOR
	MOV     BH,0
	INT     10H
	MOV	CUR_COL,DL
	MOV	CUR_ROW,DH
	INC	CUR_COL

	MOV     AH,2			;INCREASE COLUMN
	MOV     DH,CUR_ROW
	MOV     DL,CUR_COL
	MOV     BH,0
	INT     10H


	pop     di
	pop     si
	pop     dx
	pop     ax

	ret
_SET_CURSOR	endp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;	_IF_BUFFER_EMPTY	proc near...
;		THIS IS CALLED FROM THE CHAT PROC...
;	TO WAIT UNTILL THE CHARACHTER HAS BEEN SENT
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_IF_BUFFER_EMPTY	proc near

	push    ax
	push    dx
	push    si
	push    di

   CHECK_THR_EMPTY:

	MOV     DX,L_STAT              ; LINE STATUS REGISTER
	IN      AL,DX
	TEST    AL,00100000B           ;CHECK TO SEE IF TBR IS EMPTY
	JZ      CHECK_THR_EMPTY

	CHECK_TBR_EMPTY:

	MOV     DX,L_STAT              ; LINE STATUS REGISTER
	IN      AL,DX
	TEST    AL,01000000B           ;CHECK TO SEE IF TBR IS EMPTY
	JZ      CHECK_TBR_EMPTY

	pop     di
	pop     si
	pop     dx
	pop     ax

	ret
_IF_BUFFER_EMPTY	endp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;                        _DISPLAY_STRING proc near...
;	TO DISPLAY ANY STING
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
_DISPLAY_STRING proc near


	push    ax
	push    dx
	push    si
	push    di

	mov     ah,9            ;OUTPUT THE MENU
	int     21h

	pop     di
	pop     si
	pop     dx
	pop     ax

	ret

_DISPLAY_STRING endp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;			_SCROLL_UP	PROC
;		THIS IS CALLED FROM THE CHAT PROC
;	SCROLLS ONE LINE JUST BELOW THE MENU
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_SCROLL_UP	proc near

	push    ax
	push    dx
	push    si
	push	di
	push	cx

	mov     ah,6
	mov     al,1
	mov     ch,4
	mov     cl,0
	mov     dh,24
	mov     dl,79
	mov     dh,10000001b
	int     10h

	MOV     AH,2
	MOV     DH,23
	MOV     DL,0
	MOV     BH,0
	INT     10H


	pop		cx
	pop     di
	pop     si
	pop     dx
	pop     ax

	ret
_SCROLL_UP	endp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;				_ENTER_PRESSED	proc near...
;			THIS IS CALLED FROM THE CHAT PROC
;				goes to the new line
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_ENTER_PRESSED	proc near

	push    ax
	push    dx
	push    si
	push    di

	MOV     AH,3
	MOV     BH,0
	INT     10H
	MOV     CUR_ROW,DH

	INC     CUR_ROW

	MOV     AH,2
	MOV     DH,CUR_ROW
	MOV     DL,0
	MOV     BH,0
	INT     10H

	pop     di
	pop     si
	pop     dx
	pop     ax


	ret
_ENTER_PRESSED	endp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;                        _SEND_STRING   PROC  near
;      	TO SEND ANY OTHER STRING TO THE MODEM OUT OF CHAT PROC
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_SEND_STRING   PROC  near

	GO:
	MOV     DX,PORT
	MOV     AL,[DI]
	OUT     DX,AL   		;send the charachter to the port

	HOLD:	   			;hold untill the char is sent

	MOV     AH,3			;STATUS FUNCTION
	MOV     DX,1
	int     14H

	TEST    AH,00100000B
	JZ      HOLD

	INC     DI
	LOOP    GO

	ret
_SEND_STRING	ENDP

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;                           _BACK_SPACE	proc	near
;			   CALLED FROM THE CHAT PROC
;			   MOVE THE CURSOR TO THE LEFT
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_BACK_SPACE	proc	near

	push    ax
	push    dx
	push    si
	push    di

	MOV     AH,3
	MOV     BH,0
	INT     10H
	MOV	CUR_COL,DL
	MOV	CUR_ROW,DH

	CMP	CUR_COL,1
	JB	NO

	DEC	CUR_COL
	MOV     AH,2
	MOV     DH,CUR_ROW
	MOV     DL,CUR_COL
	MOV     BH,0
	INT     10H

  NO:

	pop     di
	pop     si
	pop     dx
	pop     ax

	ret

_BACK_SPACE	endp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;		_HANG_UP	PROC...
;	CALLED FROM THE CHAT PROC TO HANG UO THE MODEM
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_HANG_UP	proc near

	PUSH	di
	PUSH	CX

	DELAY  10		;CALL THE MACRO THE GET A DELAY FOR A SECOND

	mov	di,offset hang_1
	mov	cx,3
	CALL	_SEND_STRING

	DELAY  10

	mov	di,offset hang_2
	mov	cx,4
	CALL	_SEND_STRING

	POP		CX
	POP		DI

	RET

_HANG_UP	endp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;                   _ANSWER	proc	near...
;CALLED FROM THE CHAT PROC TO ANSWER THE INCOMING CALL
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_ANSWER	proc	near

	push	di
	push	cx

	mov		di,offset answer
	mov		cx,4
	CALL	_SEND_STRING

	pop		cx
	pop		di

	ret

_ANSWER	endp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;                _CLRSCR	proc near
;	CLEAR THE SCREEN:BY DIRECTLY CLEARING THE SCREEN
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_CLRSCR	proc near

	PUSH	AX
	PUSH	DI
	PUSH	CX


	MOV     AX,0B800H
	MOV     ES,AX

	mov     ah,7
	MOV     AL,' '
	MOV     DI,0
	Mov     cx,2000
	REP     stosW

	m_LocateCursor 0,0

	POP	CX
	POP	DI
	POP	AX

	ret
_CLRSCR	endp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;		EXIT
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_EXIT	proc near


	MOV	 DX,PORT
	MOV  	 AL,0
	OUT	 DX,AL

	MOV	AX,4C00H
	INT	21H
	ret

_EXIT	endp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

_TEXT ENDS
end
;;;;;;;;;;;;;;;;;;;;END OF .ASM FILE;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;